***************************************************************
***************************************************************
***															***
***		THE LONG WALK TO KNOWLEDGE: ON THE DETERMINANTS		***
***			OF HIGHER EDUCATION MOBILITY TO EUROPE			***
***															***
***	Jonas DIDISSE, Thanh Tam NGUYEN-HUU, Thi Anh-Dao TRAN	***
***															***
***************************************************************
***************************************************************


**	NOTE:
**	Commands are available to export tables in latex, excel or word formats (in this order).
**	Please uncomment the appropriate lines to activate the execution.
**	Outreg2 package (http://repec.org/bocode/o/outreg2.html) is used to do this.
**	You can install the package by uncommenting and running the following line:

* ssc install outreg2



** For any request or suggestion, please contact the authors:
** Jonas Didisse ; CREAM, University of Rouen ; jonas.didisse1@univ-rouen.fr
** Thanh Tam Nguyen-Huu ; CREAM, University of Rouen ; TIMAS, Thang-Long University ; huu-thanh-tam.nguyen@univ-rouen.fr
** Thi Anh-Dao Tran ; CREAM, University of Rouen ; thianh-dao.tran@univ-rouen.fr



clear
set more off


***************** PATHS *****************

*cd "Your path"



***************** OPENING THE DATABASE *****************

use "LongWalkToKnowledge_Database.dta", clear



***************** SUMMARY STATICS *****************

summarize
*outreg2 using "LongWalkToKnowledge_SummaryStatistics.tex", replace sum(log)
*outreg2 using "LongWalkToKnowledge_SummaryStatistics.doc", replace sum(log)
*outreg2 using "LongWalkToKnowledge_SummaryStatistics.xls", replace sum(log)




***************** DATA MANIPULATIONS *****************

**** Variable rescaling (logarithms) ****

gen logAS_ij=log(AS_ij)
gen logStock_ij=log(Stock_ij+1)
gen logIN_ij=log(IN_ij+1)
gen logFN_ij=log(FN_ij+1)
gen logDist_ij=log(Dist_ij)
gen logGDPcap_i=log(GDPcap_i)
gen logEnrol_i=log(Enrol_i)
gen logAS_i=log(AS_i+1)
gen logEnrol_j=log(Enrol_j)
gen logRanking_j=log(Ranking_j+1)

**** Home & Host dummies ****

set more off
encode iso_i, gen(id_i)
encode iso_j, gen(id_j)
tab iso_i, gen(home_)
tab iso_j, gen(host_)


**** Macro definition ****

global Home1 "logGDPcap_i Yu_i logEnrol_i logAS_i"
global Home2 "Conflicts_i Tension_i Freedleav_i Integration_i HEqual_i HEadapt_i Prospects_i Irregular_i Merit_i Relucthire_i" 
global Host1 "PLI_j logEnrol_j Genderratio_j"
global Host2 "HEqual_j HEadapt_j logRanking_j Healthqual_j Migrants_j"




***************** ROLE OF NETWORKS *****************

**** Poisson Pseudo-Maximum Likelihood ****

set more off

ppml AS_ij logStock_ij logDist_ij Col45_ij COL_ij home_* host_*, cluster(logDist_ij) nocon
*outreg2 using "LongWalkToKnowledge_RoleOfNetworks.tex", title(Role of Networks: PPML) drop(home_* host_*) sortvar(logStock_ij logIN_ij logFN_ij logDist_ij Col45_ij COL_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) replace
*outreg2 using "LongWalkToKnowledge_RoleOfNetworks.doc", title(Role of Networks: PPML) drop(i.id_i i.id_j) sortvar(logStock_ij logIN_ij logFN_ij logDist_ij Col45_ij COL_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) replace
*outreg2 using "LongWalkToKnowledge_RoleOfNetworks.xls", title(Role of Networks: PPML) drop(i.id_i i.id_j) sortvar(logStock_ij logIN_ij logFN_ij logDist_ij Col45_ij COL_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) replace

ppml AS_ij logIN_ij logDist_ij Col45_ij COL_ij home_* host_*, cluster(logDist_ij) nocon
*outreg2 using "LongWalkToKnowledge_RoleOfNetworks.tex", title(Role of Networks: PPML) drop(home_* host_*) sortvar(logStock_ij logIN_ij logFN_ij logDist_ij Col45_ij COL_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfNetworks.doc", title(Role of Networks: PPML) drop(i.id_i i.id_j) sortvar(logStock_ij logIN_ij logFN_ij logDist_ij Col45_ij COL_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfNetworks.xls", title(Role of Networks: PPML) drop(i.id_i i.id_j) sortvar(logStock_ij logIN_ij logFN_ij logDist_ij Col45_ij COL_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append

ppml AS_ij logFN_ij logDist_ij Col45_ij COL_ij home_* host_*, cluster(logDist_ij) nocon
*outreg2 using "LongWalkToKnowledge_RoleOfNetworks.tex", title(Role of Networks: PPML) drop(home_* host_*) sortvar(logStock_ij logIN_ij logFN_ij logDist_ij Col45_ij COL_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfNetworks.doc", title(Role of Networks: PPML) drop(i.id_i i.id_j) sortvar(logStock_ij logIN_ij logFN_ij logDist_ij Col45_ij COL_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfNetworks.xls", title(Role of Networks: PPML) drop(i.id_i i.id_j) sortvar(logStock_ij logIN_ij logFN_ij logDist_ij Col45_ij COL_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append



**** Endogeneity test: IV-PPML ****

** Informal Network **

gen IV=(Internet_i*log(Pop1564_j))

set more off

ivpoisson cfunction AS_ij (logIN_ij = IV) logDist_ij Col45_ij CSL_ij i.id_i i.id_j
*outreg2 using "LongWalkToKnowledge_IVPPML_Informal.tex", title(Role of Networks: Endogeneity of IN) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij CSL_ij IV) drop(i.id_i i.id_j) ctitle(IV-PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) replace
*outreg2 using "LongWalkToKnowledge_IVPPML_Informal.doc", title(Role of Networks: Endogeneity of IN) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij CSL_ij IV) drop(i.id_i i.id_j) ctitle(IV-PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) replace
*outreg2 using "LongWalkToKnowledge_IVPPML_Informal.xls", title(Role of Networks: Endogeneity of IN) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij CSL_ij IV) drop(i.id_i i.id_j) ctitle(IV-PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) replace

ivpoisson cfunction AS_ij (logIN_ij = IV) logFN_ij logDist_ij Col45_ij CSL_ij i.id_i i.id_j
*outreg2 using "LongWalkToKnowledge_IVPPML_Informal.tex", title(Role of Networks: Endogeneity of IN) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij CSL_ij IV) drop(i.id_i i.id_j) ctitle(IV-PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) append
*outreg2 using "LongWalkToKnowledge_IVPPML_Informal.doc", title(Role of Networks: Endogeneity of IN) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij CSL_ij IV) drop(i.id_i i.id_j) ctitle(IV-PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) append
*outreg2 using "LongWalkToKnowledge_IVPPML_Informal.xls", title(Role of Networks: Endogeneity of IN) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij CSL_ij IV) drop(i.id_i i.id_j) ctitle(IV-PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) append


** Formal Network **

set more off

ivpoisson cfunction AS_ij (logFN_ij = FTA_ij) logDist_ij Col45_ij CSL_ij i.id_i i.id_j
*outreg2 using "LongWalkToKnowledge_IVPPML_Formal3.tex", title(Role of Networks: Endogeneity of FN) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij CSL_ij FTA_ij) drop(i.id_i i.id_j) ctitle(IV-PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) replace
*outreg2 using "LongWalkToKnowledge_IVPPML_Formal3.doc", title(Role of Networks: Endogeneity of FN) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij CSL_ij FTA_ij) drop(i.id_i i.id_j) ctitle(IV-PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) replace
*outreg2 using "LongWalkToKnowledge_IVPPML_Formal3.xls", title(Role of Networks: Endogeneity of FN) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij CSL_ij FTA_ij) drop(i.id_i i.id_j) ctitle(IV-PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) replace

ivpoisson cfunction AS_ij (logFN_ij = FTA_ij) logIN_ij logDist_ij Col45_ij CSL_ij i.id_i i.id_j
*outreg2 using "LongWalkToKnowledge_IVPPML_Formal3.tex", title(Role of Networks: Endogeneity of FN) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij CSL_ij FTA_ij) drop(i.id_i i.id_j) ctitle(IV-PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) append
*outreg2 using "LongWalkToKnowledge_IVPPML_Formal3.doc", title(Role of Networks: Endogeneity of FN) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij CSL_ij FTA_ij) drop(i.id_i i.id_j) ctitle(IV-PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) append
*outreg2 using "LongWalkToKnowledge_IVPPML_Formal3.xls", title(Role of Networks: Endogeneity of FN) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij CSL_ij FTA_ij) drop(i.id_i i.id_j) ctitle(IV-PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) append



		
***************** ROLE OF LANGUAGES *****************

**** Poisson Pseudo-Maximum Likelihood ****

set more off

ppml AS_ij logIN_ij logDist_ij Col45_ij COL_ij home_* host_*, cluster(logDist_ij) nocon
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.tex", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) replace
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.doc", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) replace
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.xls", title(Role of Languages) drop(home_* host_* sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) replace

ppml AS_ij logIN_ij logDist_ij Col45_ij CSL_ij home_* host_*, cluster(logDist_ij) nocon
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.tex", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.doc", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.xls", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append

ppml AS_ij logIN_ij logDist_ij Col45_ij CNL_ij home_* host_*, cluster(logDist_ij) nocon
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.tex", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.doc", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.xls", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append

ppml AS_ij logIN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij home_* host_*, cluster(logDist_ij) nocon
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.tex", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.doc", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.xls", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append

ppml AS_ij logIN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij home_* host_*, cluster(logDist_ij) nocon
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.tex", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.doc", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.xls", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append

ppml AS_ij logFN_ij logDist_ij Col45_ij COL_ij home_* host_*, cluster(logDist_ij) nocon
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.tex", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.doc", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.xls", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append

ppml AS_ij logFN_ij logDist_ij Col45_ij CSL_ij home_* host_*, cluster(logDist_ij) nocon
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.tex", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.doc", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.xls", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append

ppml AS_ij logFN_ij logDist_ij Col45_ij CNL_ij home_* host_*, cluster(logDist_ij) nocon
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.tex", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.doc", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.xls", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append

ppml AS_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij home_* host_*, cluster(logDist_ij) nocon
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.tex", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.doc", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.xls", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append

ppml AS_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij home_* host_*, cluster(logDist_ij) nocon
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.tex", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.doc", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_RoleOfLanguages.xls", title(Role of Languages) drop(home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, Yes, Origin fixed effects, Yes, Numbers of origin country, 89, Numbers of destination country, 30) e(ll) append



**** Robustess test: Heckman Procedure ****

set more off

* Informal networks

heckman logAS_ij logIN_ij logDist_ij Col45_ij COL_ij home_* host_*, select(logIN_ij logDist_ij Col45_ij COL_ij home_* host_*) twostep vce(boot)
*outreg2 using "LongWalkToKnowledge_Heckman_Informal.tex", title(Heckman Procedure: Informal Networks) drop(i.id_i i.id_j home_* host_*)sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) replace
*outreg2 using "LongWalkToKnowledge_Heckman_Informal.doc", title(Heckman Procedure: Informal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) replace
*outreg2 using "LongWalkToKnowledge_Heckman_Informal.xls", title(Heckman Procedure: Informal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) replace

heckman logAS_ij logIN_ij logDist_ij Col45_ij CSL_ij home_* host_*, select(logIN_ij logDist_ij Col45_ij CSL_ij home_* host_*) twostep vce(boot)
*outreg2 using "LongWalkToKnowledge_Heckman_Informal.tex", title(Heckman Procedure: Informal Networks) drop(i.id_i i.id_j home_* host_*)sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_Informal.doc", title(Heckman Procedure: Informal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_Informal.xls", title(Heckman Procedure: Informal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append

heckman logAS_ij logIN_ij logDist_ij Col45_ij CNL_ij home_* host_*, select(logIN_ij logDist_ij Col45_ij CNL_ij home_* host_*) twostep vce(boot)
*outreg2 using "LongWalkToKnowledge_Heckman_Informal.tex", title(Heckman Procedure: Informal Networks) drop(i.id_i i.id_j home_* host_*)sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_Informal.doc", title(Heckman Procedure: Informal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_Informal.xls", title(Heckman Procedure: Informal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append

heckman logAS_ij logIN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij home_* host_*, select(logIN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij home_* host_*) twostep vce(boot)
*outreg2 using "LongWalkToKnowledge_Heckman_Informal.tex", title(Heckman Procedure: Informal Networks) drop(i.id_i i.id_j home_* host_*)sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_Informal.doc", title(Heckman Procedure: Informal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_Informal.xls", title(Heckman Procedure: Informal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append

heckman logAS_ij logIN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij home_* host_*, select(logIN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij home_* host_*) twostep vce(boot)
*outreg2 using "LongWalkToKnowledge_Heckman_Informal.tex", title(Heckman Procedure: Informal Networks) drop(i.id_i i.id_j home_* host_*)sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_Informal.doc", title(Heckman Procedure: Informal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_Informal.xls", title(Heckman Procedure: Informal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append


*Formal networks

heckman logAS_ij logFN_ij logDist_ij Col45_ij COL_ij home_* host_*, select(logFN_ij logDist_ij Col45_ij COL_ij home_* host_*) twostep vce(boot)
*outreg2 using "LongWalkToKnowledge_Heckman_Formal.tex", title(Heckman Procedure: Formal Networks) drop(i.id_i i.id_j home_* host_*)sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) replace
*outreg2 using "LongWalkToKnowledge_Heckman_Formal.doc", title(Heckman Procedure: Formal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) replace
*outreg2 using "LongWalkToKnowledge_Heckman_Formal.xls", title(Heckman Procedure: Formal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) replace

heckman logAS_ij logFN_ij logDist_ij Col45_ij CSL_ij home_* host_*, select(logFN_ij logDist_ij Col45_ij CSL_ij home_* host_*) twostep vce(boot)
*outreg2 using "LongWalkToKnowledge_Heckman_Formal.tex", title(Heckman Procedure: Formal Networks) drop(i.id_i i.id_j home_* host_*)sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_Formal.doc", title(Heckman Procedure: Formal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_Formal.xls", title(Heckman Procedure: Formal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append

heckman logAS_ij logFN_ij logDist_ij Col45_ij CNL_ij home_* host_*, select(logFN_ij logDist_ij Col45_ij CNL_ij home_* host_*) twostep vce(boot)
*outreg2 using "LongWalkToKnowledge_Heckman_Formal.tex", title(Heckman Procedure: Formal Networks) drop(i.id_i i.id_j home_* host_*)sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_Formal.doc", title(Heckman Procedure: Formal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_Formal.xls", title(Heckman Procedure: Formal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append

heckman logAS_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij home_* host_*, select(logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij home_* host_*) twostep vce(boot)
*outreg2 using "LongWalkToKnowledge_Heckman_Formal.tex", title(Heckman Procedure: Formal Networks) drop(i.id_i i.id_j home_* host_*)sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_Formal.doc", title(Heckman Procedure: Formal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_Formal.xls", title(Heckman Procedure: Formal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append

heckman logAS_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij home_* host_*, select(logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij home_* host_*) twostep vce(boot)
*outreg2 using "LongWalkToKnowledge_Heckman_Formal.tex", title(Heckman Procedure: Formal Networks) drop(i.id_i i.id_j home_* host_*)sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_Formal.doc", title(Heckman Procedure: Formal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_Formal.xls", title(Heckman Procedure: Formal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append


*Informal and Formal networks

heckman logAS_ij logIN_ij logFN_ij logDist_ij Col45_ij COL_ij home_* host_*, select(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij home_* host_*) twostep vce(boot)
*outreg2 using "LongWalkToKnowledge_Heckman_InformalFormal.tex", title(Heckman Procedure: Informal and Formal Networks) drop(i.id_i i.id_j home_* host_*)sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) replace
*outreg2 using "LongWalkToKnowledge_Heckman_InformalFormal.doc", title(Heckman Procedure: Informal and Formal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) replace
*outreg2 using "LongWalkToKnowledge_Heckman_InformalFormal.xls", title(Heckman Procedure: Informal and Formal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) replace

heckman logAS_ij logIN_ij logFN_ij logDist_ij Col45_ij CSL_ij home_* host_*, select(logIN_ij logFN_ij logDist_ij Col45_ij CSL_ij home_* host_*) twostep vce(boot)
*outreg2 using "LongWalkToKnowledge_Heckman_InformalFormal.tex", title(Heckman Procedure: Informal and Formal Networks) drop(i.id_i i.id_j home_* host_*)sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_InformalFormal.doc", title(Heckman Procedure: Informal and Formal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_InformalFormal.xls", title(Heckman Procedure: Informal and Formal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append

heckman logAS_ij logIN_ij logFN_ij logDist_ij Col45_ij CNL_ij home_* host_*, select(logIN_ij logFN_ij logDist_ij Col45_ij CNL_ij home_* host_*) twostep vce(boot)
*outreg2 using "LongWalkToKnowledge_Heckman_InformalFormal.tex", title(Heckman Procedure: Informal and Formal Networks) drop(i.id_i i.id_j home_* host_*)sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_InformalFormal.doc", title(Heckman Procedure: Informal and Formal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_InformalFormal.xls", title(Heckman Procedure: Informal and Formal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append

heckman logAS_ij logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij home_* host_*, select(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij home_* host_*) twostep vce(boot)
*outreg2 using "LongWalkToKnowledge_Heckman_InformalFormal.tex", title(Heckman Procedure: Informal and Formal Networks) drop(i.id_i i.id_j home_* host_*)sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_InformalFormal.doc", title(Heckman Procedure: Informal and Formal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_InformalFormal.xls", title(Heckman Procedure: Informal and Formal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append

heckman logAS_ij logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij home_* host_*, select(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij home_* host_*) twostep vce(boot)
*outreg2 using "LongWalkToKnowledge_Heckman_InformalFormal.tex", title(Heckman Procedure: Informal and Formal Networks) drop(i.id_i i.id_j home_* host_*)sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_InformalFormal.doc", title(Heckman Procedure: Informal and Formal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_Heckman_InformalFormal.xls", title(Heckman Procedure: Informal and Formal Networks) drop(i.id_i i.id_j home_* host_*) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij ) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append




***************** COMPLETE MODEL *****************

set more off

ppml AS_ij logIN_ij logFN_ij logDist_ij Col45_ij CSL_ij $Home1 $Home2 $Host1 $Host2 , cluster(logDist_ij)
*outreg2 using "LongWalkToKnowledge_CompleteModel.tex", title(Complete Model (PPML)) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij logGDPcap_i Yu_i logEnrol_i logAS_i Conflicts_i Tension_i Freedleav_i Integration_i HEqual_i HEadapt_i Prospects_i Irregular_i Merit_i Relucthire_i PLI_j logEnrol_j Genderratio_j HEqual_j HEadapt_j logRanking_j Healthqual_j Migrants_j) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) replace
*outreg2 using "LongWalkToKnowledge_CompleteModel.doc", title(Complete Model (PPML)) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij logGDPcap_i Yu_i logEnrol_i logAS_i Conflicts_i Tension_i Freedleav_i Integration_i HEqual_i HEadapt_i Prospects_i Irregular_i Merit_i Relucthire_i PLI_j logEnrol_j Genderratio_j HEqual_j HEadapt_j logRanking_j Healthqual_j Migrants_j) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) replace
*outreg2 using "LongWalkToKnowledge_CompleteModel.xls", title(Complete Model (PPML)) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij logGDPcap_i Yu_i logEnrol_i logAS_i Conflicts_i Tension_i Freedleav_i Integration_i HEqual_i HEadapt_i Prospects_i Irregular_i Merit_i Relucthire_i PLI_j logEnrol_j Genderratio_j HEqual_j HEadapt_j logRanking_j Healthqual_j Migrants_j) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) replace

ppml AS_ij logIN_ij logDist_ij Col45_ij CSL_ij $Home1 $Home2 $Host1 $Host2 , cluster(logDist_ij)
*outreg2 using "LongWalkToKnowledge_CompleteModel.tex", title(Complete Model (PPML)) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij logGDPcap_i Yu_i logEnrol_i logAS_i Conflicts_i Tension_i Freedleav_i Integration_i HEqual_i HEadapt_i Prospects_i Irregular_i Merit_i Relucthire_i PLI_j logEnrol_j Genderratio_j HEqual_j HEadapt_j logRanking_j Healthqual_j Migrants_j) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_CompleteModel.doc", title(Complete Model (PPML)) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij logGDPcap_i Yu_i logEnrol_i logAS_i Conflicts_i Tension_i Freedleav_i Integration_i HEqual_i HEadapt_i Prospects_i Irregular_i Merit_i Relucthire_i PLI_j logEnrol_j Genderratio_j HEqual_j HEadapt_j logRanking_j Healthqual_j Migrants_j) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
*outreg2 using "LongWalkToKnowledge_CompleteModel.xls", title(Complete Model (PPML)) sortvar(logIN_ij logFN_ij logDist_ij Col45_ij COL_ij CSL_ij CNL_ij LP_ij logGDPcap_i Yu_i logEnrol_i logAS_i Conflicts_i Tension_i Freedleav_i Integration_i HEqual_i HEadapt_i Prospects_i Irregular_i Merit_i Relucthire_i PLI_j logEnrol_j Genderratio_j HEqual_j HEadapt_j logRanking_j Healthqual_j Migrants_j) ctitle(PPML) bdec(3) alpha(0.001, 0.01, 0.05, 0.1) sym(***, **, *, +) addtext(Destination fixed effects, No, Origin fixed effects, No, Numbers of origin country, 79, Numbers of destination country, 30) e(ll) append
